@@ -2,6 +2,8 @@ use crate::window::WinitWindowBackend;
 use crate::{keyboard, mouse};
 use glutin::event_loop::ControlFlow;
 use notan_app::{FrameState, WindowConfig};
+use std::cell::RefCell;
+use std::rc::Rc;
 
 #[cfg(feature = "drop_files")]
 use notan_app::DroppedFile;
@@ -9,6 +11,10 @@ use notan_app::DroppedFile;
 use notan_app::{
     App, Backend, BackendSystem, DeviceBackend, Event, EventIterator, InitializeFn, WindowBackend,
 };
+#[cfg(feature = "audio")]
+use notan_audio::AudioBackend;
+#[cfg(feature = "audio")]
+use notan_oddio::OddioBackend;
 use winit::event::{Event as WEvent, WindowEvent};
 use winit::event_loop::EventLoop;
 
@@ -250,6 +256,12 @@ impl BackendSystem for WinitBackend {
             notan_glow::GlowBackend::new(|s| ctx.get_proc_address(s) as *const _).unwrap();
         Box::new(backend)
     }
+
+    #[cfg(feature = "audio")]
+    fn get_audio_backend(&self) -> Rc<RefCell<dyn AudioBackend>> {
+        let backend = OddioBackend::new().unwrap();
+        Rc::new(RefCell::new(backend))
+    }
 }
 
 fn backend(app: &mut App) -> &mut WinitBackend {
